Package 'powerbrmsINLA'

Title: Bayesian Power Analysis Using 'brms' and 'INLA'
Description: Provides tools for Bayesian power analysis and assurance calculations using the statistical frameworks of 'brms' and 'INLA'. Includes simulation-based approaches, support for multiple decision rules (direction, threshold, ROPE), sequential designs, and visualisation helpers. Methods are based on Kruschke (2014, ISBN:9780124058880) "Doing Bayesian Data Analysis: A Tutorial with R, JAGS, and Stan", O'Hagan & Stevens (2001) <doi:10.1177/0272989X0102100307> "Bayesian Assessment of Sample Size for Clinical Trials of Cost-Effectiveness", Kruschke (2018) <doi:10.1177/2515245918771304> "Rejecting or Accepting Parameter Values in Bayesian Estimation", Rue et al. (2009) <doi:10.1111/j.1467-9868.2008.00700.x> "Approximate Bayesian inference for latent Gaussian models by using integrated nested Laplace approximations", and Bürkner (2017) <doi:10.18637/jss.v080.i01> "brms: An R Package for Bayesian Multilevel Models using Stan".
Authors: Tony Myers [aut, cre] (ORCID: <https://orcid.org/0000-0003-4516-4829>)
Maintainer: Tony Myers <[email protected]>
License: MIT + file LICENSE
Version: 1.2.0
Built: 2026-06-03 11:07:05 UTC
Source: https://github.com/tony-myers/powerbrmsinla

Help Index